cb424d7448
verify-patch-sanity.py validates every active recipe .patch has internally- consistent hunk line counts — catching the 'malformed patch at line N' failure at commit/CI/preflight time instead of hours into a cook. This cycle hit that class three times (qtwaylandscanner, sddm, xwayland), each only discovered when cookbook tried to apply the patch. Running it across the repo found 29 latent malformed patches (validated against GNU patch: e.g. relibc/P3-sysv-ipc reproduces 'malformed patch at line 22'). They were harmless only because they sit in vendored recipes (baked, not re- applied) — but would fail on any version-bump re-derivation. --fix recounts the hunk headers (body untouched) and repaired all 29. Wired into build-preflight.sh (Phase 1.0D) and redbear-ci.yml, with a unit test (test-patch-sanity.sh). Skips archived/legacy trees and unvalidatable formats (empty placeholders, bare-@@ git hunks).
81 lines
2.2 KiB
Plaintext
81 lines
2.2 KiB
Plaintext
// RUN: %clang_cc1 -std=c++14 %s -triple nvptx64-nvidia-cuda \
|
|
// RUN: -fcuda-is-device -verify -fsyntax-only
|
|
// RUN: %clang_cc1 -std=c++17 %s -triple nvptx64-nvidia-cuda \
|
|
// RUN: -fcuda-is-device -verify -fsyntax-only
|
|
// RUN: %clang_cc1 -std=c++14 %s \
|
|
// RUN: -triple x86_64-unknown-linux-gnu -verify -fsyntax-only
|
|
// RUN: %clang_cc1 -std=c++17 %s \
|
|
// RUN: -triple x86_64-unknown-linux-gnu -verify -fsyntax-only
|
|
#include "Inputs/cuda.h"
|
|
|
|
template<typename T>
|
|
__host__ __device__ void foo(const T **a) {
|
|
// expected-note@-1 {{declared here}}
|
|
static const T b = sizeof(a);
|
|
static constexpr T c = sizeof(a);
|
|
const T d = sizeof(a);
|
|
constexpr T e = sizeof(a);
|
|
constexpr T f = **a;
|
|
// expected-error@-1 {{constexpr variable 'f' must be initialized by a constant expression}}
|
|
// expected-note@-2 {{}}
|
|
a[0] = &b;
|
|
a[1] = &c;
|
|
a[2] = &d;
|
|
a[3] = &e;
|
|
}
|
|
|
|
__device__ void device_fun(const int **a) {
|
|
// expected-note@-1 {{declared here}}
|
|
constexpr int b = sizeof(a);
|
|
static constexpr int c = sizeof(a);
|
|
constexpr int d = **a;
|
|
// expected-error@-1 {{constexpr variable 'd' must be initialized by a constant expression}}
|
|
// expected-note@-2 {{}}
|
|
a[0] = &b;
|
|
a[1] = &c;
|
|
foo(a);
|
|
// expected-note@-1 {{in instantiation of function template specialization 'foo<int>' requested here}}
|
|
}
|
|
|
|
void host_fun(const int **a) {
|
|
// expected-note@-1 {{declared here}}
|
|
constexpr int b = sizeof(a);
|
|
static constexpr int c = sizeof(a);
|
|
constexpr int d = **a;
|
|
// expected-error@-1 {{constexpr variable 'd' must be initialized by a constant expression}}
|
|
// expected-note@-2 {{}}
|
|
a[0] = &b;
|
|
a[1] = &c;
|
|
foo(a);
|
|
}
|
|
|
|
__host__ __device__ void host_device_fun(const int **a) {
|
|
// expected-note@-1 {{declared here}}
|
|
constexpr int b = sizeof(a);
|
|
static constexpr int c = sizeof(a);
|
|
constexpr int d = **a;
|
|
// expected-error@-1 {{constexpr variable 'd' must be initialized by a constant expression}}
|
|
// expected-note@-2 {{}}
|
|
a[0] = &b;
|
|
a[1] = &c;
|
|
foo(a);
|
|
}
|
|
|
|
template <class T>
|
|
struct A {
|
|
explicit A() = default;
|
|
};
|
|
template <class T>
|
|
constexpr A<T> a{};
|
|
|
|
struct B {
|
|
static constexpr bool value = true;
|
|
};
|
|
|
|
template<typename T>
|
|
struct C {
|
|
static constexpr bool value = T::value;
|
|
};
|
|
|
|
__constant__ const bool &x = C<B>::value;
|